@@ -55,7 +55,7 @@ int razer_get_report(struct usb_device *usb_dev, struct razer_report *request_re
 struct razer_report razer_send_payload(struct usb_device *usb_dev, struct razer_report *request_report)
 {
     int retval = -1;
-    struct razer_report response_report;
+    struct razer_report response_report = {0};
 
     request_report->crc = razer_calculate_crc(request_report);
 
@@ -66,7 +66,7 @@ struct razer_report razer_send_payload(struct usb_device *usb_dev, struct razer_
         if(response_report.remaining_packets != request_report->remaining_packets ||
            response_report.command_class != request_report->command_class ||
            response_report.command_id.id != request_report->command_id.id) {
-            print_erroneous_report(&response_report, "razercore", "Response doesnt match request");
+            print_erroneous_report(&response_report, "razercore", "Response doesn't match request");
 //		} else if (response_report.status == RAZER_CMD_BUSY) {
 //			print_erroneous_report(&response_report, "razercore", "Device is busy");
         } else if (response_report.status == RAZER_CMD_FAILURE) {
@@ -91,7 +91,7 @@ struct razer_report razer_send_payload(struct usb_device *usb_dev, struct razer_
 static ssize_t razer_attr_read_set_brightness(struct device *dev, struct device_attribute *attr, char *buf)
 {
     struct razer_core_device *device = dev_get_drvdata(dev);
-    struct razer_report response;
+    struct razer_report response = {0};
     struct razer_report report = razer_chroma_standard_get_led_brightness(VARSTORE, BACKLIGHT_LED);;
 
     mutex_lock(&device->lock);
@@ -110,7 +110,7 @@ static ssize_t razer_attr_read_set_brightness(struct device *dev, struct device_
 static ssize_t razer_attr_write_set_brightness(struct device *dev, struct device_attribute *attr, const char *buf, size_t count)
 {
     struct razer_core_device *device = dev_get_drvdata(dev);
-    struct razer_report report;
+    struct razer_report report = {0};
     unsigned char brightness = (unsigned char)simple_strtoul(buf, NULL, 10);
 
     report = razer_chroma_standard_set_led_brightness(VARSTORE, BACKLIGHT_LED, brightness);
@@ -131,7 +131,7 @@ static ssize_t razer_attr_read_get_firmware_version(struct device *dev, struct d
 {
     struct razer_core_device *device = dev_get_drvdata(dev);
     struct razer_report report = razer_chroma_standard_get_firmware_version();
-    struct razer_report response_report;
+    struct razer_report response_report = {0};
 
     mutex_lock(&device->lock);
     response_report = razer_send_payload(device->usb_dev, &report);
@@ -160,7 +160,7 @@ static ssize_t razer_attr_read_get_serial(struct device *dev, struct device_attr
     struct razer_core_device *device = dev_get_drvdata(dev);
     char serial_string[23];
     struct razer_report report = razer_chroma_standard_get_serial();
-    struct razer_report response_report;
+    struct razer_report response_report = {0};
 
     mutex_lock(&device->lock);
     response_report = razer_send_payload(device->usb_dev, &report);
@@ -243,7 +243,7 @@ static ssize_t razer_attr_write_mode_spectrum(struct device *dev, struct device_
 static ssize_t razer_attr_write_mode_reactive(struct device *dev, struct device_attribute *attr, const char *buf, size_t count)
 {
     struct razer_core_device *device = dev_get_drvdata(dev);
-    struct razer_report report;
+    struct razer_report report = {0};
 
     if(count == 4) {
         unsigned char speed = (unsigned char)buf[0];
@@ -265,7 +265,7 @@ static ssize_t razer_attr_write_mode_reactive(struct device *dev, struct device_
 static ssize_t razer_attr_write_mode_breath(struct device *dev, struct device_attribute *attr, const char *buf, size_t count)
 {
     struct razer_core_device *device = dev_get_drvdata(dev);
-    struct razer_report report;
+    struct razer_report report = {0};
 
     mutex_lock(&device->lock);
     switch(count) {
@@ -317,7 +317,7 @@ static ssize_t razer_attr_write_mode_custom(struct device *dev, struct device_at
 static ssize_t razer_attr_write_mode_static(struct device *dev, struct device_attribute *attr, const char *buf, size_t count)
 {
     struct razer_core_device *device = dev_get_drvdata(dev);
-    struct razer_report report;
+    struct razer_report report = {0};
 
     if(count == 3) {
         report = razer_chroma_standard_matrix_effect_static(VARSTORE, BACKLIGHT_LED, (struct razer_rgb*)&buf[0]);
@@ -343,7 +343,7 @@ static ssize_t razer_attr_write_mode_static(struct device *dev, struct device_at
 static ssize_t razer_attr_write_set_key_row(struct device *dev, struct device_attribute *attr, const char *buf, size_t count)
 {
     struct razer_core_device *device = dev_get_drvdata(dev);
-    struct razer_report report;
+    struct razer_report report = {0};
     size_t offset = 0;
     unsigned char row_id;
     unsigned char start_col;
@@ -400,7 +400,7 @@ static ssize_t razer_attr_write_set_key_row(struct device *dev, struct device_at
 static ssize_t razer_attr_write_device_mode(struct device *dev, struct device_attribute *attr, const char *buf, size_t count)
 {
     struct razer_core_device *device = dev_get_drvdata(dev);
-    struct razer_report report;
+    struct razer_report report = {0};
 
     if(count == 2) {
         report = razer_chroma_standard_set_device_mode(buf[0], buf[1]);
@@ -424,7 +424,7 @@ static ssize_t razer_attr_read_device_mode(struct device *dev, struct device_att
 {
     struct razer_core_device *device = dev_get_drvdata(dev);
     struct razer_report report = razer_chroma_standard_get_device_mode();
-    struct razer_report response;
+    struct razer_report response = {0};
 
     mutex_lock(&device->lock);
     response = razer_send_payload(device->usb_dev, &report);
