@@ -12,14 +12,7 @@
 #ifndef __HID_RAZER_CORE_H
 #define __HID_RAZER_CORE_H
 
-// TODO MOVE TO COMMON
-#ifndef USB_VENDOR_ID_RAZER
-#define USB_VENDOR_ID_RAZER 0x1532
-#endif
-
-#ifndef USB_DEVICE_ID_RAZER_CORE
 #define USB_DEVICE_ID_RAZER_CORE 0x0215
-#endif
 
 /* Each report has 90 bytes*/
 #define RAZER_CORE_REPORT_LEN 0x5A
